==> haskell-tasty-golden-2.3.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-IiMdRwAbYLjAC1kaKgngAB
key: tasty-golden-2.3.2-IiMdRwAbYLjAC1kaKgngAB
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: d86deffda0b78ee7bc2d282c26b041a9
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-IiMdRwAbYLjAC1kaKgngAB
depends:
    base-4.11.1.0 tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU filepath-1.4.2
    temporary-1.3-3R0RmfXoqZ8KVgvjtCKKNQ
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH=82080caf5dc3107fc22e84ac0a1da579
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             temporary-1.3-3R0RmfXoqZ8KVgvjtCKKNQ=c61c076f49d5515d1c87b60192e6f959
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-J823DGA52d890j2mB0Tlp5
key: tasty-golden-2.3.2-J823DGA52d890j2mB0Tlp5
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 97901794bf265c5f48e255ac89c06a06
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-J823DGA52d890j2mB0Tlp5
depends:
    base-4.11.1.0 tasty-1.1.0.3-6fyKFEs78SpAPFE4Kl16xw
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.2.0-HP9LUm9H1yn1LWZqqMzXaQ filepath-1.4.2
    temporary-1.3-9IxYk8pkVXF9czeubVUZPj
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.3-6fyKFEs78SpAPFE4Kl16xw=54a8a5dc8045d1252c8fe427ecd3498e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.2.0-HP9LUm9H1yn1LWZqqMzXaQ=6826b8c28690283a16ba755021eeafca
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             temporary-1.3-9IxYk8pkVXF9czeubVUZPj=8c49ba414a57a9d4be6d5ca675bed1f1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
